summaryrefslogtreecommitdiffstats
path: root/tdeui/kbugreport.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdeui/kbugreport.h')
-rw-r--r--tdeui/kbugreport.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/tdeui/kbugreport.h b/tdeui/kbugreport.h
index 419ad3c81..2c60b091b 100644
--- a/tdeui/kbugreport.h
+++ b/tdeui/kbugreport.h
@@ -25,7 +25,7 @@ class TQMultiLineEdit;
class TQLineEdit;
class TQHButtonGroup;
class KProcess;
-class KAboutData;
+class TDEAboutData;
class KBugReportPrivate;
/**
@@ -33,8 +33,8 @@ class KBugReportPrivate;
*
* All the information needed by the dialog box
* (program name, version, bug-report address, etc.)
* comes from the KAboutData class.
* Make sure you create an instance of KAboutData and pass it
* to TDECmdLineArgs.
*
* @author David Faure <faure@kde.org>
@@ -49,7 +49,7 @@ public:
* since KHelpMenu takes care of the menu item
* for "Report Bug..." and of creating a KBugReport dialog.
*/
- KBugReport( TQWidget * parent = 0L, bool modal=true, const KAboutData *aboutData = 0L );
+ KBugReport( TQWidget * parent = 0L, bool modal=true, const TDEAboutData *aboutData = 0L );
/**
* Destructor
*/
@@ -101,7 +101,7 @@ protected:
bool sendBugReport();
KProcess * m_process;
- const KAboutData * m_aboutData;
+ const TDEAboutData * m_aboutData;
TQMultiLineEdit * m_lineedit;
TQLineEdit * m_subject;
@@ -33,8 +33,8 @@ class KBugReportPrivate;
* All the information needed by the dialog box
* (program name, version, bug-report address, etc.)
- * comes from the KAboutData class.
- * Make sure you create an instance of KAboutData and pass it
+ * comes from the TDEAboutData class.
+ * Make sure you create an instance of TDEAboutData and pass it
* to TDECmdLineArgs.
*